@@ -1,6 +1,6 @@
 .onLoad <- function(lib, pkg) {
     if (interactive()) {
         if (!is.null(getOption("guiToolkit")))
-            try(formatR(getOption("guiToolkit")))
+            try(tidy.gui(getOption("guiToolkit")))
     }
 }
